/**
 *   File:  UART_drv.h 
 *
 *   Def's for PIC32MX UART driver library supporting UART1 and UART2.
 */
#ifndef UART_LIB_H
#define UART_LIB_H

#include <sys/attribs.h>    // For interrupt handlers
#include "../system_def.h"
#include "../HardwareProfile.h"

//================  UART DRIVER BUILD OPTIONS  ========================
// If these symbols are not already defined in "HardwareProfile.h",
// the following default settings will be applied...
//
#ifndef UART1_RX_INTERRUPT_DRIVEN
#define UART1_RX_INTERRUPT_DRIVEN  0   // if 0, use polled RX input
#define UART2_RX_INTERRUPT_DRIVEN  0   // if 0, use polled RX input
#endif

#ifndef UART1_TX_USING_QUEUE
#define UART1_TX_USING_QUEUE  0    // if 0, use direct TX functions
#define UART2_TX_USING_QUEUE  0    // if 0, use direct TX functions
#endif

#ifndef UART1_TXBUFSIZE
#define UART1_TXBUFSIZE      128   // TX FIFO buffer size, chars
#define UART2_TXBUFSIZE      128
#endif

#ifndef UART1_RXBUFSIZE
#define UART1_RXBUFSIZE      256   // RX FIFO buffer size, chars
#define UART2_RXBUFSIZE      256
#endif
//
//=====================================================================

#define UART1_RX_IRQ_DISABLE()   IEC0bits.U1RXIE = 0
#define UART1_RX_IRQ_ENABLE()    IEC0bits.U1RXIE = 1
#define UART1_RX_IRQ_CLEAR()     IFS0bits.U1RXIF = 0  
#define UART1_ERR_IRQ_CLEAR()    IFS0bits.U1EIF = 0  

#define UART2_RX_IRQ_DISABLE()   IEC1bits.U2RXIE = 0
#define UART2_RX_IRQ_ENABLE()    IEC1bits.U2RXIE = 1
#define UART2_RX_IRQ_CLEAR()     IFS1bits.U2RXIF = 0
#define UART2_ERR_IRQ_CLEAR()    IFS1bits.U2EIF = 0  


void   UART1_init( uint16 br );
uint8  UART1_RxDataAvail(void);
void   UART1_RxFlush(void);
uint8  UART1_getch( void );
uint8  UART1_putch( uint8 b );
void   UART1_putstr( char *pstr );
void   UART1_TxQueueHandler();

void   UART2_init( uint16 br );
uint8  UART2_RxDataAvail(void);
void   UART2_RxFlush(void);
uint8  UART2_getch( void );
uint8  UART2_putch( uint8 b );
void   UART2_putstr( char *pstr );
void   UART2_TxQueueHandler();

#endif // UART_LIB_H
