/****************************************************************************************
 *
 * FileName:   main_pic32_audio_test.h 
 *
 * File contains build options and particular def's for the application.
 * See also: "HardwareProfile.h"
 *
 * =======================================================================================
 */
#ifndef _MAIN_PIC32_AUDIO_TEST_H
#define _MAIN_PIC32_AUDIO_TEST_H

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <math.h>

#include "system_def.h"
#include "Drivers/EEPROM_drv.h"
#include "console_cli.h"
#include "pic32_low_level.h"    // multi-platform def's
#include "pic32_audio_test_cli.h"


// =======================================================================================
//                       FIRMWARE VERSION NUMBER AND BUILD OPTIONS
//
#define BUILD_VER_MAJOR   1
#define BUILD_VER_MINOR   0
#define BUILD_VER_DEBUG   30
//
// =======================================================================================

#define SAMPLE_RATE_HZ        (40000)    // For wave-table Oscillators
#define PARTIAL_ORDER_MAX          16    // Highest partial order for waveform generator
#define WAVE_TABLE_MAXIMUM_SIZE  2600    // Samples

#define FIXED_MIN_LEVEL  (1)                     // Minimum normalized signal level (0.0001)
#define FIXED_MAX_LEVEL  (IntToFixedPt(1) - 1)   // Full-scale normalized signal level (0.9999)
#define FIXED_PT_HALF    (IntToFixedPt(1) / 2)   // Constant 0.5 in fixed_t format

#define NOISE_WAVE      0
#define SINE_WAVE       1
#define TRIANG_WAVE     2
#define SQUARE_WAVE     3
#define RAMP_WAVE       4


// This descriptor is used to access wave-tables defined in flash PM
//
typedef struct Flash_Wave_Table_Descriptor
{
    uint16  Size;          // Table size, samples
    float   FreqDiv;       // Osc Freq Divider
    int16  *Address;       // Address of wave-table data
    
} FlashWaveTable_t;


enum  Self_test_categories
{
    TEST_SOFTWARE_TIMER = 0,
    TEST_DEVICE_ID,
    TEST_MIDI_IN_COMMS,
    TEST_EEPROM,
    NUMBER_OF_SELFTEST_ITEMS
};


extern  uint8   g_FW_version[];        // firmware version # (major, minor, build, 0)
extern  int     g_SoftTimerError;      // % error
extern  uint8   g_SelfTestFault[];     // Self-test fault codes (0 => no fault)
extern  uint32  g_counter;             // temp, for debug
extern  bool    g_RangeSwitchingTestActive;
extern  int     g_RangeSwitchingPeriod_ms;

extern  const  FlashWaveTable_t   g_FlashWaveTableDef[];  // Array of flash-based wave-tables

extern  const  int16   g_sinewave[];
extern  const  int16   g_square_wave[];
extern  const  int16   g_triangle_wave[];
extern  const  int16   g_sawtooth_wave[];


// Public functions defined in "main_pic32_audio_test.c" available to external modules:
//
void   SynthInit();
void   SynthOscStart();
void   SynthOscStop();

void   WaveTableSizeSet(uint16 size);
void   OscFreqDividerSet(float freqDiv);
float  OscFreqDividerGet();
bool   isSynthActive();
void   SetAudioOutputLevel(fixed_t level_pu);

// -------- Functions defined in "remi_synth_data.c" ----------
//
int    GetNumberOfFlashWaveTables();


#endif // _MAIN_PIC32_AUDIO_TEST_H
